<?php

/**
 * @file
 * Building of custom add content page.
 */

/**
 * Render of custom_add_content_page menu items.
 *
 * @ingroup themeable
 */
function theme_jstree_menu_menu($variables) {
  $id = $variables['id'];
  $tree = $variables['tree'];

  if (is_array($tree) && count($tree) > 0) {
    $output = '<div id="menu-jstree-' . $id . '">';
    $output .= jstree_menu_renderer($tree);
    $output .= '</div>';
  }
  else {
    $output = '<p>' . t('You have not created any menu items for this menu yet') . '</p>';
  }

  return $output;
}

/**
 * Module's tree renderer.
 */
function jstree_menu_renderer($tree) {
  $node_url = NULL;
  $node = menu_get_object('node');
  if (!empty($node)) {
    $node_url = 'node/' . $node->nid;
  }

  $output = '<ul class="menu-jstree">';
  foreach ($tree as $item) {
    $link = $item['link'];
    $below = $item['below'];
    if ($link['hidden'] != 1) {
      $link = l($link['title'], $link['href'], $link['localized_options']);
      if (count($below) > 0) {
        if (jstree_menu_is_active_link($below, $node_url)) {
          $output .= '<li data-jstree=\'{"opened":true, "icon":"glyphicon glyphicon-tag"}\'>' . $link;
        }
        else {
          $output .= '<li data-jstree=\'{"icon":"glyphicon glyphicon-tag"}\'>' . $link;
        }
        $output .= jstree_menu_renderer($below);
        $output .= '</li>';
      }
      else {
        $output .= '<li data-jstree=\'{"icon":"glyphicon glyphicon-ok"}\'>' . $link . '</li>';
      }
    }
  }
  $output .= '</ul>';

  return $output;
}

/**
 * Detect if current tree element should be active.
 */
function jstree_menu_is_active_link($below, $node_url) {
  $active = FALSE;

  foreach($below as $child) {

    if (count($child['below']) > 0) {
      $active = jstree_menu_is_active_link($child['below'], $node_url);
    }

    if ($child['link']['link_path'] == $node_url) {
      $active = TRUE;
    }

    if ($active) {
      return $active;
    }
  }

  return $active;
}
